summaryrefslogtreecommitdiff
path: root/lisp/emacs-lisp
diff options
context:
space:
mode:
Diffstat (limited to 'lisp/emacs-lisp')
-rw-r--r--lisp/emacs-lisp/package-vc.el6
1 files changed, 3 insertions, 3 deletions
diff --git a/lisp/emacs-lisp/package-vc.el b/lisp/emacs-lisp/package-vc.el
index 96cf7bb4666..ae0f7e0ee14 100644
--- a/lisp/emacs-lisp/package-vc.el
+++ b/lisp/emacs-lisp/package-vc.el
@@ -28,8 +28,8 @@
;; aren't interested in activating a package, you can use
;; `package-vc-checkout' instead, which will prompt you for a target
;; directory. If you wish to re-use an existing checkout, the command
;; `package-vc-link-directory' will create a symbolic link and prepare
;; the package.
;;
;; If you make local changes that you wish to share with an upstream
;; maintainer, the command `package-vc-prepare-patch' can prepare
@@ -665,7 +665,7 @@ for the last released version of the package."
(find-file directory)))
;;;###autoload
-(defun package-vc-link-directory (dir name)
+(defun package-vc-install-from-checkout (dir name)
"Set up the package NAME in DIR by linking it into the ELPA directory.
Interactively, prompt the user for DIR, which should be a directory
under version control, typically one created by `package-vc-checkout'.
@@ -28,8 +28,8 @@
;; `package-vc-checkout' instead, which will prompt you for a target
;; directory. If you wish to re-use an existing checkout, the command
-;; `package-vc-link-directory' will create a symbolic link and prepare
-;; the package.
+;; `package-vc-install-from-checkout' will create a symbolic link and
+;; prepare the package.
;;
;; If you make local changes that you wish to share with an upstream